# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2023-04-03 14:45:50
:LastEditTime: 2023-04-03 15:31:37
:LastEditors: HuangJingCan
:Description: 
"""
from seven_jd.jd.api.rest import *
from seven_jd.jd.api.base import FileItem